svn: /web/doc-editor/trunk/scripts/cron/ check_build.php

[email protected] (Yannick Torres)
Newsgroups php.doc.web
Message-ID <[email protected]>
yannick                                  Mon, 31 Oct 2011 17:57:55 +0000

Revision: http://svn.php.net/viewvc?view=revision&revision=318616

Log:
Now, all exclude language work aren't realy build.. :/

Changed paths:
    U   web/doc-editor/trunk/scripts/cron/check_build.php

Modified: web/doc-editor/trunk/scripts/cron/check_build.php
===================================================================
--- web/doc-editor/trunk/scripts/cron/check_build.php	2011-10-31 17:42:18 UTC (rev 318615)
+++ web/doc-editor/trunk/scripts/cron/check_build.php	2011-10-31 17:57:55 UTC (rev 318616)
@@ -18,8 +18,8 @@
 $availableProject = $pm->getAvailableProject();


-// Don't send email for this lang code: ar,bg,cs,nl,el,he,pt,sl,sv
-$dontSendEmail = array("ar","bg","cs","nl","no","el","he","pt","sl","sv");
+// Don't build for this lang code: ar,bg,cs,nl,el,he,pt,sl,sv
+$dontBuild = array("ar","bg","cs","nl","no","el","he","pt","sl","sv");

 while( list($key, $project) = each($availableProject) ) {

@@ -44,7 +44,7 @@
     // For all language, we check the build
     foreach ($existingLanguage as $lang) {

-        if( in_array($lang, $dontSendEmail) ) {
+        if( in_array($lang["code"], $dontBuild) ) {
             echo "Exclude build for this language\n";
             continue;
         }
@@ -55,8 +55,7 @@

         $lock = new LockFile('project_'.$pm->project.'_lock_check_build_'.$lang);
         if ($lock->lock()) {
-
-
+
             $return = $rm->checkBuild($lang);

             // What we must do when the build failed
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.